{% load i18n %}
<div class="row">
    <div class="col-xs-12">
        <dl>

            {% if 'DESCRIPTION_E62' not in report_info.source.graph %}
                <dd class="arches-report-subsection-item">
                    {% trans "No descriptions recorded" %}
                </dd>
            {% else %}
                {% for DESCRIPTION_E62 in report_info.source.graph.DESCRIPTION_E62 %}
                    <dt>
                        <h5 id="" class="arches-report-subsection-title">{{DESCRIPTION_E62.DESCRIPTION_TYPE_E55__value}}</h5>
                    </dt>
                    <dd class="arches-report-subsection-item arches-report-spacer">
                        {% if report_info.source.graph.DESCRIPTION_E62|length == 1 or report_info.source.graph.DESCRIPTION_E62.last %}
                            {{ DESCRIPTION_E62.DESCRIPTION_E62__value |safe }}
                        {% else %}
                            {{ DESCRIPTION_E62.DESCRIPTION_E62__value |safe }}
                            <br></br>
                        {% endif %}

                    </dd>
                {% endfor %}            
            {% endif %}

        </dl>
    </div>
</div>