{% load i18n %}
<!-- Add Button -->
<div class="btn-group" style="margin-left: 5px;">
    <button type="button" class="add-button btn btn-primary" style="height: 32px;">{% trans "Add" %}</button>
    <button type="button" class="btn btn-primary dropdown-toggle" style="height: 32px;" data-toggle="dropdown">
        <i class="fa fa-chevron-down"></i>
        <span class="sr-only">{% trans "Toggle Dropdown" %}</span>                            
    </button>
    <ul class="dropdown-menu" role="menu">
        <li><a href="#" name="discard-edit-link">{% trans "Discard edits" %}</a></li>
    </ul>
</div>
<!-- End Add Button -->