{% load i18n %}
<div class="row">
     <div class="col-xs-12">
        <dl>
            <dt>
                <h5 id="" class="arches-report-subsection-title">{% trans "Names" %}</h5>
            </dt>

            {% if 'NAME_E41' not in report_info.source.graph %}
                <dd class="arches-report-subsection-item">
                    {% trans "No names recorded" %}
                </dd>
            {% else %}
                {% for NAME_E41 in report_info.source.graph.NAME_E41 %}
                    <dd class="arches-report-subsection-item">
                        {{ NAME_E41.NAME_E41__value }} <span class="arches-report-subsection-item-type">({{NAME_E41.NAME_TYPE_E55__value}})</span>
                    </dd>
                {% endfor %}            
            {% endif %}

        </dl>
    </div>
</div>