
<!--
ARCHES - a program developed to inventory and manage immovable cultural heritage.
Copyright (C) 2013 J. Paul Getty Trust and World Monuments Fund

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
-->
{% load staticfiles %}
{% load i18n %}

{% include 'views/reports/title.htm' %}

<!-- End Fixed Nav for Report -->
<div id="report-body" class="report-body">
    
     {% if geometry != 'null' %}
        <!--=== Map Block ===-->
        <div id="map-container">

            <div id="map" class="map map-report-panel" style="display: block;">
                <div id="olmap" class="fill"></div>
                <div style="display:none;" id="map-data">
                    <input type="hidden" id="resource_geometry" value='{{ geometry }}' />
                </div>
            </div>

            <!-- Map: Project Info Panel -->
            <div class="container">
                
                <!-- Map Tools Panel -->
                <div class="row">
                    <div class="col-xs-12 col-sm-6" style="">

                        <div id="basemaps-panel" class="tools-panel hidden" style="overflow-y: scroll; border-top-left-radius: 5px; border-top-right-radius: 5px; margin-top: -408px; height: 332px; width: 290px; margin-left: 0px;">
                            <div class="modal-header arches-modal-header">
                                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">
                                    ×
                                </button>
                                <h4 class="modal-title">
                                    {% trans "Basemaps" %}
                                </h4>
                            </div>

                            <!-- Body Content -->
                            <div class="modal-body padding-top-0 padding-bottom-0" data-bind='foreach: baseLayers'>

                                <div class="row">
                                    <hr class="arches-layer-divider" style="border-top: 0px; margin-top: 5px;">

                                    <div class="arches-basemap-entry" style="margin-right: 7px;">
                                        
                                        <div class="" style="">
                                            <a data-bind="attr: { id: id, title: name }" class="basemap info-click" data-rel="" href="javascript:void(0);">
                                                <span class="">  
                                                    <img data-bind="attr: { src: icon }" class="arches-basemap-thumbnail" alt="" />
                                                    <span class="zoom-icon"></span>                   
                                                </span>                                              
                                            </a>                    
                                            <span class="arches-basemap-caption-search">
                                                <a data-bind="attr: { id: id }, text: name" class="caption-text-search hover-effect basemap info-click" href="javascript:void(0);"> </a>
                                            </span>
                                        </div>

                                    </div>
                                </div>

                            </div>
                            <!-- End Body Content -->

                        </div>
                    </div>
                </div>
                <!-- End Map Tools Panel -->

                <!-- Map Tools -->
                <div class="row">
                    <div class="col-xs-12 col-sm-7 col-md-5 col-lg-4" style="margin-top: -77px;">
                        <div class="btn-group">
                            <button id="inventory-basemaps" type="button" class="btn btn-primary arches-map-tools" style="width:290px;"><i class="fa fa-globe"></i> {% trans "Basemaps" %}
                            </button>
                        </div>
                    </div>
                </div>
                <!-- End Map Tools -->
            </div>
        </div>
        <!--=== End Map Block ===-->
    {% endif %}


    <!--=== Resource Description Section ===-->
    <div class="block-description" style="padding-top: 30px;" id="report">
        <div class="container">

            <!-- Resource Report Container -->
            <div>

                <!-- Section Header -->
                <div class="">
                    <i class="center-icon rounded-x fa fa-folder-open"></i>
                    <div class="">
                        <h2 class="arches-report-section-header">{% trans "Resource Description" %}</h2>
                    </div> 
                </div>

                <!-- Anchor for in=page navigation from "report options" menu -->
                <a href="overview" id="overview" style="top: 250px;"></a>


                <!-- Resource Description Content -->
                <div class="row">
                    
                    <!-- Spacer -->
                    <div class="hidden-sm hidden-md hidden-lg margin-bottom-20"></div>

                    <!-- Resource Summary Info -->
                    <div class="col-xs-12">
                        <div class="right-inner arches-box-grey-border">
                            
                            <!-- Resource Summary Info -->
                            <div class="row">

                                <!-- Section sub-header -->
                                <div class="col-sm-4">
                                    <h3 class="arches-report-subsection">{% trans "Resource Summary" %}</h3>
                                </div>
                                <!-- End Section sub-header -->

                                <!-- Section Content -->
                                <div class="col-sm-8">

                                    <!-- Spacer -->
                                    <div class="arches-report-spacer hidden-xs"></div>

                                    <div class="arches-report-subsection-content">

                                        <!-- Names -->
                                        {% include 'views/reports/sections/NAME.E41.htm' %}

                                        <!-- Important Dates -->
                                        {% include 'views/reports/sections/important_dates.htm' %}

                                        <!-- Keywords -->
                                        {% include 'views/reports/sections/KEYWORD.E55.htm' %}

                                    </div>
                                </div>
                                <!-- End Section Content-->

                            </div>
                            <!-- End Names/Type Section -->


                            <hr class="devider margin-top-10" style="margin-bottom: 5px;"></hr>

                            
                            <!-- Location -->
                            <div class="row">

                                <!-- Section sub-header -->
                                <div class="col-sm-4">
                                    <h3 class="arches-report-subsection">{% trans "Location Information" %}</h3>
                                </div>
                                <!-- End Section sub-header -->

                                 <!-- Section Content -->
                                <div class="col-sm-8">

                                    <!-- Spacer -->
                                    <div class="arches-report-spacer hidden-xs"></div>

                                    <div class="arches-report-subsection-content">

                                        <!-- Addresses -->
                                        {% include 'views/reports/sections/PLACE_ADDRESS.E45.htm' %}

                                        <!-- Location Description -->
                                        {% include 'views/reports/sections/DESCRIPTION_OF_LOCATION.E62.htm' %}

                                        <!-- Admin Ares -->
                                        {% include 'views/reports/sections/ADMINISTRATIVE_SUBDIVISION.E48.htm' %}

                                        
                                    </div>
                                </div>
                                <!-- End Section Content-->

                            </div>
                            <!-- End Location Section -->


                            <hr class="devider margin-top-10" style="margin-bottom: 5px;"></hr>


                            <!-- Classification -->
                            <div class="row">

                                <!-- Section sub-header -->
                                <div class="col-sm-4">
                                    <h3 class="arches-report-subsection">{% trans "Activity Details" %}</h3>
                                </div>
                                <!-- End Section sub-header -->

                                 <!-- Section Content -->
                                <div class="col-sm-8">

                                    <!-- Spacer -->
                                    <div class="arches-report-spacer hidden-xs"></div>

                                    <div class="arches-report-subsection-content">

                                        <!-- Classification -->
                                        <div class="row">
                                            <div class="col-xs-12">
                                                <dl>
                                                    <dt>
                                                        <h5 id="" class="arches-report-subsection-title">{% trans "Tasks" %}</h5>
                                                    </dt>

                                                    {% if 'ARCHES_ACTIVITY_PHASE.E4' not in report_info.source.graph %}
                                                        <dd class="arches-report-subsection-item">
                                                            {% trans "No classifications recorded" %}
                                                        </dd>
                                                    {% else %}

                                                        {% for ARCHES_ACTIVITY_PHASE.E4 in report_info.source.graph.ARCHES_ACTIVITY_PHASE.E4 %}
                                                            {% if 'PHASE_TYPE_ASSIGNMENT_E17' not in ARCHES_ACTIVITY_PHASE.E4 %}
                                                                <dd class="arches-report-subsection-item">
                                                                    {% trans "No classifications recorded" %}
                                                                </dd>
                                                            {% else %}
                                                                {% for PHASE_TYPE_ASSIGNMENT_E17 in ARCHES_ACTIVITY_PHASE.E4.PHASE_TYPE_ASSIGNMENT_E17 %}
                                                                    <dd class="arches-report-subsection-item arches-report-spacer">

                                                                        {% if 'ACTIVITY_TYPE_E55' in PHASE_TYPE_ASSIGNMENT_E17 %}
                                                                            <span class="arches-report-subsection-item-type">
                                                                                {% trans "Type" %}:
                                                                            </span>
                                                                            {% for ACTIVITY_TYPE_E55 in PHASE_TYPE_ASSIGNMENT_E17.ACTIVITY_TYPE_E55 %}
                                                                                {{ACTIVITY_TYPE_E55.ACTIVITY_TYPE_E55__value}}
                                                                            {% endfor %} 
                                                                        {% endif %}

                                                                        {% if 'TIME___SPAN_PHASE_E52' in PHASE_TYPE_ASSIGNMENT_E17 %}
                                                                            <span class="arches-report-subsection-item-type">
                                                                                {% trans "Dates (from/to)" %}:
                                                                            </span>
                                                                            {% for TIME___SPAN_PHASE_E52 in PHASE_TYPE_ASSIGNMENT_E17.TIME___SPAN_PHASE_E52 %}
                                                                                {% for FROM_DATE_E49 in TIME___SPAN_PHASE_E52.FROM_DATE_E49 %}
                                                                                    {{FROM_DATE_E49.FROM_DATE_E49__value}}
                                                                                {% endfor %} -
                                                                                {% for TO_DATE_E49 in TIME___SPAN_PHASE_E52.TO_DATE_E49 %}
                                                                                    {{TO_DATE_E49.TO_DATE_E49__value}}
                                                                                {% endfor %} 
                                                                            {% endfor %} 
                                                                        {% endif %}

                                                                    </dd>
                                                                {% endfor %}
                                                            {% endif %}   

                                                        {% endfor %} 

                                                    {% endif %}   

                                                </dl>
                                            </div>
                                        </div>

                                    </div>
                                </div>
                                <!-- End Section Content-->

                            </div>
                            <!-- End Classification Section -->


                            <hr class="devider margin-top-10" style="margin-bottom: 5px;"></hr>


                            <!-- Descriptions -->
                            <div class="row">

                                <!-- Section sub-header -->
                                <div class="col-sm-4">
                                    <h3 class="arches-report-subsection">{% trans "Resource Descriptions" %}</h3>
                                </div>
                                <!-- End Section sub-header -->

                                 <!-- Section Content -->
                                <div class="col-sm-8">

                                    <!-- Spacer -->
                                    <div class="arches-report-spacer hidden-xs"></div>

                                    <div class="arches-report-subsection-content">

                                        <!-- Descriptions -->
                                        {% include 'views/reports/sections/DESCRIPTION.E62.htm' %}

                                    </div>
                                </div>
                                <!-- End Section Content-->

                            </div>
                            <!-- End Descriptions Section -->


                            <hr class="devider margin-top-10" style="margin-bottom: 5px;"></hr>


                            <!-- External System References -->
                            <div class="row">

                                <!-- Section sub-header -->
                                <div class="col-sm-4">
                                    <h3 class="arches-report-subsection">{% trans "External System References" %}</h3>
                                </div>
                                <!-- End Section sub-header -->

                                 <!-- Section Content -->
                                <div class="col-sm-8">

                                    <!-- Spacer -->
                                    <div class="arches-report-spacer hidden-xs"></div>

                                    <div class="arches-report-subsection-content">

                                        <!-- Moficiations -->
                                        {% include 'views/reports/sections/EXTERNAL_XREF.E42.htm' %}

                                    </div>
                                </div>
                                <!-- End Section Content-->

                            </div>
                            <!-- End Descriptions Section -->
                        </div>
                    </div>
                    <!-- End Project Information -->
                    
                </div>   
            </div>
            <!-- End Project Summary -->
        </div>
    </div>
    <!-- End Resource Description Section -->

    {% include "views/reports/sections/related_resource_section.htm" %}

    {% include 'footer.htm' %}

    {% include 'copyright.htm' %}

</div>